==> istio-model-v1beta1-6.7.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/LoadBalancerSettingsConsistentHashLBHttpCookieBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class LoadBalancerSettingsConsistentHashLBHttpCookieBuilder extends LoadBalancerSettingsConsistentHashLBHttpCookieFluentImpl<LoadBalancerSettingsConsistentHashLBHttpCookieBuilder> implements VisitableBuilder<LoadBalancerSettingsConsistentHashLBHttpCookie,LoadBalancerSettingsConsistentHashLBHttpCookieBuilder>{
  public LoadBalancerSettingsConsistentHashLBHttpCookieBuilder() {
    this(false);
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieBuilder(Boolean validationEnabled) {
    this(new LoadBalancerSettingsConsistentHashLBHttpCookie(), validationEnabled);
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieBuilder(LoadBalancerSettingsConsistentHashLBHttpCookieFluent<?> fluent) {
    this(fluent, false);
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieBuilder(LoadBalancerSettingsConsistentHashLBHttpCookieFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new LoadBalancerSettingsConsistentHashLBHttpCookie(), validationEnabled);
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieBuilder(LoadBalancerSettingsConsistentHashLBHttpCookieFluent<?> fluent,LoadBalancerSettingsConsistentHashLBHttpCookie instance) {
    this(fluent, instance, false);
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieBuilder(LoadBalancerSettingsConsistentHashLBHttpCookieFluent<?> fluent,LoadBalancerSettingsConsistentHashLBHttpCookie instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withHttpCookie(instance.getHttpCookie());
    }
    this.validationEnabled = validationEnabled; 
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieBuilder(LoadBalancerSettingsConsistentHashLBHttpCookie instance) {
    this(instance,false);
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieBuilder(LoadBalancerSettingsConsistentHashLBHttpCookie instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withHttpCookie(instance.getHttpCookie());
    }
    this.validationEnabled = validationEnabled; 
  }
  LoadBalancerSettingsConsistentHashLBHttpCookieFluent<?> fluent;
  Boolean validationEnabled;
  public LoadBalancerSettingsConsistentHashLBHttpCookie build() {
    LoadBalancerSettingsConsistentHashLBHttpCookie buildable = new LoadBalancerSettingsConsistentHashLBHttpCookie(fluent.getHttpCookie());
    return buildable;
  }
  
}

==> istio-model-v1beta1-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/LoadBalancerSettingsConsistentHashLBHttpCookieBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class LoadBalancerSettingsConsistentHashLBHttpCookieBuilder extends LoadBalancerSettingsConsistentHashLBHttpCookieFluent<LoadBalancerSettingsConsistentHashLBHttpCookieBuilder> implements VisitableBuilder<LoadBalancerSettingsConsistentHashLBHttpCookie,LoadBalancerSettingsConsistentHashLBHttpCookieBuilder>{
  public LoadBalancerSettingsConsistentHashLBHttpCookieBuilder() {
    this(false);
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieBuilder(Boolean validationEnabled) {
    this(new LoadBalancerSettingsConsistentHashLBHttpCookie(), validationEnabled);
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieBuilder(LoadBalancerSettingsConsistentHashLBHttpCookieFluent<?> fluent) {
    this(fluent, false);
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieBuilder(LoadBalancerSettingsConsistentHashLBHttpCookieFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new LoadBalancerSettingsConsistentHashLBHttpCookie(), validationEnabled);
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieBuilder(LoadBalancerSettingsConsistentHashLBHttpCookieFluent<?> fluent,LoadBalancerSettingsConsistentHashLBHttpCookie instance) {
    this(fluent, instance, false);
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieBuilder(LoadBalancerSettingsConsistentHashLBHttpCookieFluent<?> fluent,LoadBalancerSettingsConsistentHashLBHttpCookie instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new LoadBalancerSettingsConsistentHashLBHttpCookie());

    if (instance != null) {
      fluent.withHttpCookie(instance.getHttpCookie());
      fluent.withHttpCookie(instance.getHttpCookie());
    }
    this.validationEnabled = validationEnabled; 
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieBuilder(LoadBalancerSettingsConsistentHashLBHttpCookie instance) {
    this(instance,false);
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieBuilder(LoadBalancerSettingsConsistentHashLBHttpCookie instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new LoadBalancerSettingsConsistentHashLBHttpCookie());

    if (instance != null) {
      this.withHttpCookie(instance.getHttpCookie());
      this.withHttpCookie(instance.getHttpCookie());
    }
    this.validationEnabled = validationEnabled; 
  }
  LoadBalancerSettingsConsistentHashLBHttpCookieFluent<?> fluent;
  Boolean validationEnabled;
  public LoadBalancerSettingsConsistentHashLBHttpCookie build() {
    LoadBalancerSettingsConsistentHashLBHttpCookie buildable = new LoadBalancerSettingsConsistentHashLBHttpCookie(fluent.buildHttpCookie());
    return buildable;
  }
  
}
